@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2006 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-only
 */
@@ -39,8 +40,10 @@ private Q_SLOTS:
     void testTraderConstraints();
 #endif
     void testSubseqConstraints();
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 104)
     void testHasServiceType1();
     void testHasServiceType2();
+#endif
 #if KSERVICE_BUILD_DEPRECATED_SINCE(5, 66)
     void testWriteServiceTypeProfile();
 #endif
@@ -65,11 +68,16 @@ private Q_SLOTS:
 #endif
     void testCompleteBaseName();
     void testEntryPathToName();
+    void testMimeType();
+    void testProtocols();
 
 #if KSERVICE_BUILD_DEPRECATED_SINCE(5, 90)
     void testTraderQueryMustRebuildSycoca();
 #endif
 
+    void testAliasFor();
+    void testServiceActionService();
+
 private:
     void createFakeService(const QString &filenameSuffix, const QString &serviceType);
     void runKBuildSycoca(bool noincremental = false);
