@@ -1,21 +1,10 @@
-/*  This file is part of the KDE libraries
- *  Copyright (C) 1999 Waldo Bastian <bastian@kde.org>
- *  Copyright (C) 2006-2007 David Faure <faure@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2006-2007 David Faure <faure@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KMIMETYPEFACTORY_H
 #define KMIMETYPEFACTORY_H
@@ -24,16 +13,16 @@
 
 #include <QStringList>
 
-#include "ksycocafactory_p.h"
 #include "ksycocaentry_p.h"
+#include "ksycocafactory_p.h"
 
 class KSycoca;
 
 /**
  * @internal  - this header is not installed
  *
- * A sycoca factory for mimetype entries
- * This is only used to point to the "service offers" in ksycoca for each mimetype.
+ * A sycoca factory for MIME type entries
+ * This is only used to point to the "service offers" in ksycoca for each MIME type.
  * @see KMimeType
  */
 class KMimeTypeFactory : public KSycocaFactory
@@ -57,12 +46,12 @@ public:
     }
 
     /**
-     * Returns the possible offset for a given mimetype entry.
+     * Returns the possible offset for a given MIME type entry.
      */
     int entryOffset(const QString &mimeTypeName);
 
     /**
-     * Returns the offset into the service offers for a given mimetype.
+     * Returns the offset into the service offers for a given MIME type.
      */
     int serviceOffersOffset(const QString &mimeTypeName);
 
@@ -73,18 +62,18 @@ public:
 
 public:
     /**
-     * @return all mimetypes
+     * @return all MIME types
      * Slow and memory consuming, avoid using
      */
     QStringList allMimeTypes();
 
     /**
-     * @return the unique mimetype factory, creating it if necessary
+     * @return the unique MIME type factory, creating it if necessary
      */
     static KMimeTypeFactory *self();
 
 public: // public for KBuildServiceFactory
-    // A small entry for each mimetype with name and offset into the services-offer-list.
+    // A small entry for each MIME type with name and offset into the services-offer-list.
     class MimeTypeEntryPrivate;
     class KSERVICE_EXPORT MimeTypeEntry : public KSycocaEntry
     {
@@ -94,7 +83,7 @@ public: // public for KBuildServiceFactory
 
         MimeTypeEntry(const QString &file, const QString &name);
         MimeTypeEntry(QDataStream &s, int offset);
-        ~MimeTypeEntry();
+        ~MimeTypeEntry() override;
 
         int serviceOffersOffset() const;
         void setServiceOffersOffset(int off);
@@ -104,9 +93,10 @@ public: // public for KBuildServiceFactory
 
 protected:
     MimeTypeEntry *createEntry(int offset) const override;
+
 private:
     // d pointer: useless since this header is not installed
-    //class KMimeTypeFactoryPrivate* d;
+    // class KMimeTypeFactoryPrivate* d;
 };
 
 #endif
