@@ -1,28 +1,15 @@
-/*  This file is part of the KDE libraries
- *  Copyright (C) 1999-2006 David Faure <faure@kde.org>
- *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License or ( at
- *  your option ) version 3 or, at the discretion of KDE e.V. ( which shall
- *  act as a proxy as in section 14 of the GPLv3 ), any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- **/
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999-2006 David Faure <faure@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
+
+#include "kservice.h"
 #include "kservicefactory_p.h"
 #include "ksycoca.h"
-#include "ksycocatype.h"
 #include "ksycocadict_p.h"
-#include "kservice.h"
+#include "ksycocatype.h"
 #include "servicesdebug.h"
 #include <QDir>
 #include <QFile>
@@ -30,10 +17,10 @@
 extern int servicesDebugArea();
 
 KServiceFactory::KServiceFactory(KSycoca *db)
-    : KSycocaFactory(KST_KServiceFactory, db),
-      m_nameDict(nullptr),
-      m_relNameDict(nullptr),
-      m_menuIdDict(nullptr)
+    : KSycocaFactory(KST_KServiceFactory, db)
+    , m_nameDict(nullptr)
+    , m_relNameDict(nullptr)
+    , m_menuIdDict(nullptr)
 {
     m_offerListOffset = 0;
     m_nameDictOffset = 0;
@@ -77,7 +64,7 @@ KServiceFactory::~KServiceFactory()
 KService::Ptr KServiceFactory::findServiceByName(const QString &_name)
 {
     if (!sycocaDict()) {
-        return KService::Ptr();    // Error!
+        return KService::Ptr(); // Error!
     }
 
     // Warning : this assumes we're NOT building a database
@@ -86,7 +73,7 @@ KService::Ptr KServiceFactory::findServiceByName(const QString &_name)
 
     int offset = sycocaDict()->find_string(_name);
     if (!offset) {
-        return KService::Ptr();    // Not found
+        return KService::Ptr(); // Not found
     }
 
     KService::Ptr newService(createEntry(offset));
@@ -102,7 +89,7 @@ KService::Ptr KServiceFactory::findServiceByName(const QString &_name)
 KService::Ptr KServiceFactory::findServiceByDesktopName(const QString &_name)
 {
     if (!m_nameDict) {
-        return KService::Ptr();    // Error!
+        return KService::Ptr(); // Error!
     }
 
     // Warning : this assumes we're NOT building a database
@@ -110,7 +97,7 @@ KService::Ptr KServiceFactory::findServiceByDesktopName(const QString &_name)
 
     int offset = m_nameDict->find_string(_name);
     if (!offset) {
-        return KService::Ptr();    // Not found
+        return KService::Ptr(); // Not found
     }
 
     KService::Ptr newService(createEntry(offset));
@@ -126,7 +113,7 @@ KService::Ptr KServiceFactory::findServiceByDesktopName(const QString &_name)
 KService::Ptr KServiceFactory::findServiceByDesktopPath(const QString &_name)
 {
     if (!m_relNameDict) {
-        return KService::Ptr();    // Error!
+        return KService::Ptr(); // Error!
     }
 
     // Warning : this assumes we're NOT building a database
@@ -134,7 +121,7 @@ KService::Ptr KServiceFactory::findServiceByDesktopPath(const QString &_name)
 
     int offset = m_relNameDict->find_string(_name);
     if (!offset) {
-        //qCDebug(SERVICES) << "findServiceByDesktopPath:" << _name << "not found";
+        // qCDebug(SERVICES) << "findServiceByDesktopPath:" << _name << "not found";
         return KService::Ptr(); // Not found
     }
 
@@ -155,7 +142,7 @@ KService::Ptr KServiceFactory::findServiceByDesktopPath(const QString &_name)
 KService::Ptr KServiceFactory::findServiceByMenuId(const QString &_menuId)
 {
     if (!m_menuIdDict) {
-        return KService::Ptr();    // Error!
+        return KService::Ptr(); // Error!
     }
 
     // Warning : this assumes we're NOT building a database
@@ -163,7 +150,7 @@ KService::Ptr KServiceFactory::findServiceByMenuId(const QString &_menuId)
 
     int offset = m_menuIdDict->find_string(_menuId);
     if (!offset) {
-        return KService::Ptr();    // Not found
+        return KService::Ptr(); // Not found
     }
 
     KService::Ptr newService(createEntry(offset));
@@ -229,13 +216,9 @@ KService::List KServiceFactory::allServices()
 {
     KService::List result;
     const KSycocaEntry::List list = allEntries();
-    KSycocaEntry::List::const_iterator it = list.begin();
-    const KSycocaEntry::List::const_iterator end = list.end();
-    for (; it != end; ++it) {
-        const KSycocaEntry::Ptr entry = *it;
-        if (entry->isType(KST_KService)) {
-            KService::Ptr service(static_cast<KService*>(entry.data()));
-            result.append(service);
+    for (const auto &entryPtr : list) {
+        if (entryPtr->isType(KST_KService)) {
+            result.append(KService::Ptr(static_cast<KService *>(entryPtr.data())));
         }
     }
     return result;
@@ -243,8 +226,7 @@ KService::List KServiceFactory::allServices()
 
 QStringList KServiceFactory::resourceDirs()
 {
-    return KSycocaFactory::allDirectories(QStringLiteral("kservices5"))
-           + KSycocaFactory::allDirectories(QStringLiteral("applications"));
+    return KSycocaFactory::allDirectories(QStringLiteral("kservices5")) + KSycocaFactory::allDirectories(QStringLiteral("applications"));
 }
 
 QList<KServiceOffer> KServiceFactory::offers(int serviceTypeOffset, int serviceOffersOffset)
@@ -255,7 +237,10 @@ QList<KServiceOffer> KServiceFactory::offers(int serviceTypeOffset, int serviceO
     QDataStream *str = stream();
     str->device()->seek(m_offerListOffset + serviceOffersOffset);
 
-    qint32 aServiceTypeOffset, aServiceOffset, initialPreference, mimeTypeInheritanceLevel;
+    qint32 aServiceTypeOffset;
+    qint32 aServiceOffset;
+    qint32 initialPreference;
+    qint32 mimeTypeInheritanceLevel;
     while (true) {
         (*str) >> aServiceTypeOffset;
         if (aServiceTypeOffset) {
@@ -269,15 +254,19 @@ QList<KServiceOffer> KServiceFactory::offers(int serviceTypeOffset, int serviceO
                 KService *serv = createEntry(aServiceOffset);
                 if (serv) {
                     KService::Ptr servPtr(serv);
+#if KSERVICE_BUILD_DEPRECATED_SINCE(5, 69)
                     list.append(KServiceOffer(servPtr, initialPreference, mimeTypeInheritanceLevel, servPtr->allowAsDefault()));
+#else
+                    list.append(KServiceOffer(servPtr, initialPreference, mimeTypeInheritanceLevel));
+#endif
                 }
                 // Restore position
                 str->device()->seek(savedPos);
             } else {
-                break;    // too far
+                break; // too far
             }
         } else {
-            break;    // 0 => end of list
+            break; // 0 => end of list
         }
     }
     return list;
@@ -296,13 +285,16 @@ KService::List KServiceFactory::serviceOffers(int serviceTypeOffset, int service
     QDataStream *str = stream();
     str->device()->seek(m_offerListOffset + serviceOffersOffset);
 
-    qint32 aServiceTypeOffset, aServiceOffset, initialPreference, mimeTypeInheritanceLevel;
+    qint32 aServiceTypeOffset;
+    qint32 aServiceOffset;
+    qint32 initialPreference;
+    qint32 mimeTypeInheritanceLevel;
     while (true) {
         (*str) >> aServiceTypeOffset;
         if (aServiceTypeOffset) {
             (*str) >> aServiceOffset;
-            (*str) >> initialPreference;
-            (*str) >> mimeTypeInheritanceLevel;
+            (*str) >> initialPreference; // unused (remove once KMimeTypeTrader/KServiceTypeTrader are gone)
+            (*str) >> mimeTypeInheritanceLevel; // unused (remove once KMimeTypeTrader/KServiceTypeTrader are gone)
             if (aServiceTypeOffset == serviceTypeOffset) {
                 // Save stream position !
                 const qint64 savedPos = str->device()->pos();
@@ -314,10 +306,10 @@ KService::List KServiceFactory::serviceOffers(int serviceTypeOffset, int service
                 // Restore position
                 str->device()->seek(savedPos);
             } else {
-                break;    // too far
+                break; // too far
             }
         } else {
-            break;    // 0 => end of list
+            break; // 0 => end of list
         }
     }
     return list;
@@ -337,7 +329,10 @@ bool KServiceFactory::hasOffer(int serviceTypeOffset, int serviceOffersOffset, i
     // Jump to the offer list
     str->device()->seek(m_offerListOffset + serviceOffersOffset);
     bool found = false;
-    qint32 aServiceTypeOffset, aServiceOffset, initialPreference, mimeTypeInheritanceLevel;
+    qint32 aServiceTypeOffset;
+    qint32 aServiceOffset;
+    qint32 initialPreference;
+    qint32 mimeTypeInheritanceLevel;
     while (!found) {
         (*str) >> aServiceTypeOffset;
         if (aServiceTypeOffset) {
@@ -349,10 +344,10 @@ bool KServiceFactory::hasOffer(int serviceTypeOffset, int serviceOffersOffset, i
                     found = true;
                 }
             } else {
-                break;    // too far
+                break; // too far
             }
         } else {
-            break;    // 0 => end of list
+            break; // 0 => end of list
         }
     }
     // Restore position
@@ -364,4 +359,3 @@ void KServiceFactory::virtual_hook(int id, void *data)
 {
     KSycocaFactory::virtual_hook(id, data);
 }
-
