@@ -1,72 +1,62 @@
-/*  This file is part of the KDE libraries
- *  Copyright (C) 1999 David Faure <faure@kde.org>
- *  Copyright (C) 2002-2003 Waldo Bastian <bastian@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License version 2 as published by the Free Software Foundation;
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- **/
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2002-2003 Waldo Bastian <bastian@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #include "kbuildsycoca_p.h"
 #include "ksycoca_p.h"
 #include "ksycocaresourcelist_p.h"
-#include "vfolder_menu_p.h"
 #include "ksycocautils_p.h"
 #include "sycocadebug.h"
+#include "vfolder_menu_p.h"
 
-#include <config-ksycoca.h>
-#include <kservicegroup.h>
-#include <kservice.h>
-#include "kbuildservicetypefactory_p.h"
 #include "kbuildmimetypefactory_p.h"
 #include "kbuildservicefactory_p.h"
 #include "kbuildservicegroupfactory_p.h"
+#include "kbuildservicetypefactory_p.h"
 #include "kctimefactory_p.h"
 #include <QDataStream>
+#include <QDateTime>
+#include <QDebug>
 #include <QDir>
+#include <QDirIterator>
 #include <QEventLoop>
 #include <QFile>
 #include <QLocale>
-#include <QTimer>
-#include <QDebug>
-#include <QDirIterator>
-#include <QDateTime>
 #include <QSaveFile>
+#include <QTimer>
+#include <config-ksycoca.h>
+#include <kservice.h>
+#include <kservicegroup.h>
 
 #include <kmemfile_p.h>
 
+#include <QLockFile>
+#include <QStandardPaths>
+#include <memory> // auto_ptr
 #include <qplatformdefs.h>
 #include <time.h>
-#include <memory> // auto_ptr
-#include <QStandardPaths>
-#include <QLockFile>
 
 static const char *s_cSycocaPath = nullptr;
 
-KBuildSycocaInterface::~KBuildSycocaInterface() {}
+KBuildSycocaInterface::~KBuildSycocaInterface()
+{
+}
 
 KBuildSycoca::KBuildSycoca()
-    : KSycoca(true),
-      m_allEntries(nullptr),
-      m_currentFactory(nullptr),
-      m_ctimeFactory(nullptr),
-      m_ctimeDict(nullptr),
-      m_currentEntryDict(nullptr),
-      m_serviceGroupEntryDict(nullptr),
-      m_vfolder(nullptr),
-      m_newTimestamp(0),
-      m_menuTest(false),
-      m_changed(false)
+    : KSycoca(true)
+    , m_allEntries(nullptr)
+    , m_ctimeFactory(nullptr)
+    , m_ctimeDict(nullptr)
+    , m_currentEntryDict(nullptr)
+    , m_serviceGroupEntryDict(nullptr)
+    , m_vfolder(nullptr)
+    , m_newTimestamp(0)
+    , m_menuTest(false)
+    , m_changed(false)
 {
 }
 
@@ -77,7 +67,7 @@ KBuildSycoca::~KBuildSycoca()
     factories()->clear();
 }
 
-KSycocaEntry::Ptr KBuildSycoca::createEntry(const QString &file, bool addToFactory)
+KSycocaEntry::Ptr KBuildSycoca::createEntry(KSycocaFactory *currentFactory, const QString &file)
 {
     quint32 timeStamp = m_ctimeFactory->dict()->ctime(file, m_resource);
     if (!timeStamp) {
@@ -96,7 +86,7 @@ KSycocaEntry::Ptr KBuildSycoca::createEntry(const QString &file, bool addToFacto
 
         if (timeStamp && (timeStamp == oldTimestamp)) {
             // Re-use old entry
-            if (m_currentFactory == d->m_serviceFactory) { // Strip .directory from service-group entries
+            if (currentFactory == d->m_serviceFactory) { // Strip .directory from service-group entries
                 entry = m_currentEntryDict->value(file.left(file.length() - 10));
             } else {
                 entry = m_currentEntryDict->value(file);
@@ -120,14 +110,9 @@ KSycocaEntry::Ptr KBuildSycoca::createEntry(const QString &file, bool addToFacto
     m_ctimeFactory->dict()->addCTime(file, m_resource, timeStamp);
     if (!entry) {
         // Create a new entry
-        entry = m_currentFactory->createEntry(file);
+        entry = currentFactory->createEntry(file);
     }
     if (entry && entry->isValid()) {
-        if (addToFactory) {
-            m_currentFactory->addEntry(entry);
-        } else {
-            m_tempStorage.append(entry);
-        }
         return entry;
     }
     return KSycocaEntry::Ptr();
@@ -135,14 +120,26 @@ KSycocaEntry::Ptr KBuildSycoca::createEntry(const QString &file, bool addToFacto
 
 KService::Ptr KBuildSycoca::createService(const QString &path)
 {
-    KSycocaEntry::Ptr entry = createEntry(path, false);
-    return KService::Ptr(static_cast<KService*>(entry.data()));
+    KSycocaEntry::Ptr entry = createEntry(d->m_serviceFactory, path);
+    if (entry) {
+        m_tempStorage.append(entry);
+    }
+    return KService::Ptr(static_cast<KService *>(entry.data()));
+}
+
+static QStringList locateDirInResource(const QString &resourceSubdir)
+{
+    const QString dir = QStringLiteral(":/") + resourceSubdir; // e.g. :/kservicetypes5
+    if (QDir(dir).exists()) {
+        return {dir};
+    }
+    return {};
 }
 
 // returns false if the database is up to date, true if it needs to be saved
 bool KBuildSycoca::build()
 {
-    typedef QList<KBSEntryDict *> KBSEntryDictList;
+    using KBSEntryDictList = QList<KBSEntryDict *>;
     KBSEntryDictList entryDictList;
     KBSEntryDict *serviceEntryDict = nullptr;
 
@@ -150,12 +147,12 @@ bool KBuildSycoca::build()
     entryDictList.reserve(factories()->size());
     int i = 0;
     // For each factory
-    auto list = *factories();
-    for (KSycocaFactory* factory : qAsConst(list)) {
+    const auto &factoryList = *factories();
+    for (KSycocaFactory *factory : factoryList) {
         KBSEntryDict *entryDict = new KBSEntryDict;
         if (m_allEntries) { // incremental build
-            for (const KSycocaEntry::Ptr &entry : qAsConst((*m_allEntries)[i++])) {
-                //if (entry->entryPath().contains("fake"))
+            for (const KSycocaEntry::Ptr &entry : std::as_const((*m_allEntries).at(i++))) {
+                // if (entry->entryPath().contains("fake"))
                 //    qCDebug(SYCOCA) << "inserting into entryDict:" << entry->entryPath() << entry;
                 entryDict->insert(entry->entryPath(), entry);
             }
@@ -173,40 +170,40 @@ bool KBuildSycoca::build()
     const auto lstDirs = factoryResourceDirs();
     for (const QString &dir : lstDirs) {
         qint64 stamp = 0;
-        KSycocaUtilsPrivate::visitResourceDirectory(dir, [&stamp] (const QFileInfo &info) {
+        KSycocaUtilsPrivate::visitResourceDirectory(dir, [&stamp](const QFileInfo &info) {
             stamp = qMax(stamp, info.lastModified().toMSecsSinceEpoch());
             return true;
         });
         m_allResourceDirs.insert(dir, stamp);
     }
 
+    const auto lstFiles = factoryExtraFiles();
+    for (const QString &file : lstFiles) {
+        m_extraFiles.insert(file, QFileInfo(file).lastModified().toMSecsSinceEpoch());
+    }
+
     QMap<QString, QByteArray> allResourcesSubDirs; // dirs, kstandarddirs-resource-name
     // For each factory
-    list = *factories();
-    for (KSycocaFactory* factory : qAsConst(list)) {
+    for (KSycocaFactory *factory : factoryList) {
         // For each resource the factory deals with
-        const KSycocaResourceList *list = factory->resourceList();
-        if (!list) {
-            continue;
-        }
-        for (const KSycocaResource &res : qAsConst(*list)) {
+        const KSycocaResourceList resourceList = factory->resourceList();
+        for (const KSycocaResource &res : resourceList) {
             // With this we would get dirs, but not a unique list of relative files (for global+local merging to work)
-            //const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, res.subdir, QStandardPaths::LocateDirectory);
-            //allResourcesSubDirs[res.resource] += dirs;
+            // const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, res.subdir, QStandardPaths::LocateDirectory);
+            // allResourcesSubDirs[res.resource] += dirs;
             allResourcesSubDirs.insert(res.subdir, res.resource);
         }
     }
 
     m_ctimeFactory = new KCTimeFactory(this); // This is a build factory too, don't delete!!
-    for (QMap<QString, QByteArray>::ConstIterator it1 = allResourcesSubDirs.constBegin();
-            it1 != allResourcesSubDirs.constEnd();
-            ++it1) {
+    for (auto it1 = allResourcesSubDirs.cbegin(); it1 != allResourcesSubDirs.cend(); ++it1) {
         m_changed = false;
         m_resourceSubdir = it1.key();
         m_resource = it1.value();
 
         QSet<QString> relFiles;
-        const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, m_resourceSubdir, QStandardPaths::LocateDirectory);
+        const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, m_resourceSubdir, QStandardPaths::LocateDirectory)
+            + locateDirInResource(m_resourceSubdir);
         qCDebug(SYCOCA) << "Looking for subdir" << m_resourceSubdir << "=>" << dirs;
         for (const QString &dir : dirs) {
             QDirIterator it(dir, QDirIterator::Subdirectories);
@@ -218,33 +215,26 @@ bool KBuildSycoca::build()
             }
         }
         // Now find all factories that use this resource....
-        // For each factory
-        KBSEntryDictList::const_iterator ed_it = entryDictList.constBegin();
-        const KBSEntryDictList::const_iterator ed_end = entryDictList.constEnd();
-        KSycocaFactoryList::const_iterator it = factories()->constBegin();
-        const KSycocaFactoryList::const_iterator end = factories()->constEnd();
-        for (; it != end; ++it, ++ed_it) {
-            m_currentFactory = (*it);
+        // For each factory -- and its corresponding entryDict (iterate over both lists in parallel)
+        for (int f = 0; f < factoryList.count(); ++f) {
+            KSycocaFactory *currentFactory = factoryList.at(f);
             // m_ctimeInfo gets created after the initial loop, so it has no entryDict.
-            m_currentEntryDict = ed_it == ed_end ? nullptr : *ed_it;
+            m_currentEntryDict = f == entryDictList.size() ? nullptr : entryDictList.at(f);
             // For each resource the factory deals with
-            const KSycocaResourceList *list = m_currentFactory->resourceList();
-            if (!list) {
-                continue;
-            }
-
-            for (const KSycocaResource &res : qAsConst(*list)) {
-                if (res.resource != (*it1)) {
+            const KSycocaResourceList &resourceList = currentFactory->resourceList();
+            for (const KSycocaResource &res : resourceList) {
+                if (res.resource != m_resource) {
                     continue;
                 }
 
                 // For each file in the resource
-                for (auto entryPath = relFiles.constBegin();
-                         entryPath != relFiles.constEnd();
-                        ++entryPath) {
+                for (const QString &entryPath : std::as_const(relFiles)) {
                     // Check if file matches filter
-                    if ((*entryPath).endsWith(res.extension)) {
-                        createEntry(*entryPath, true);
+                    if (entryPath.endsWith(res.extension)) {
+                        KSycocaEntry::Ptr entry = createEntry(currentFactory, entryPath);
+                        if (entry) {
+                            currentFactory->addEntry(entry);
+                        }
                     }
                 }
             }
@@ -256,7 +246,6 @@ bool KBuildSycoca::build()
     if (createVFolder || m_menuTest) {
         m_resource = "apps";
         m_resourceSubdir = QStringLiteral("applications");
-        m_currentFactory = d->m_serviceFactory;
         m_currentEntryDict = serviceEntryDict;
         m_changed = false;
 
@@ -280,7 +269,7 @@ bool KBuildSycoca::build()
             }
             if (!m_allResourceDirs.contains(dir)) {
                 qint64 stamp = 0;
-                KSycocaUtilsPrivate::visitResourceDirectory(dir, [&stamp] (const QFileInfo &info) {
+                KSycocaUtilsPrivate::visitResourceDirectory(dir, [&stamp](const QFileInfo &info) {
                     stamp = qMax(stamp, info.lastModified().toMSecsSinceEpoch());
                     return true;
                 });
@@ -306,7 +295,7 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
 {
     QString caption = caption_;
     QString name = name_;
-    for (VFolderMenu::SubMenu *subMenu : qAsConst(menu->subMenus)) {
+    for (VFolderMenu::SubMenu *subMenu : std::as_const(menu->subMenus)) {
         QString subName = name + subMenu->name + QLatin1Char('/');
 
         QString directoryFile = subMenu->directoryFile;
@@ -325,9 +314,9 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
             if (timeStamp && (timeStamp == oldTimestamp)) {
                 KSycocaEntry::Ptr group = m_serviceGroupEntryDict->value(subName);
                 if (group) {
-                    entry = KServiceGroup::Ptr(static_cast<KServiceGroup*>(group.data()));
+                    entry = KServiceGroup::Ptr(static_cast<KServiceGroup *>(group.data()));
                     if (entry->directoryEntryPath() != directoryFile) {
-                        entry = nullptr;    // Can't reuse this one!
+                        entry = nullptr; // Can't reuse this one!
                     }
                 }
             }
@@ -348,11 +337,14 @@ void KBuildSycoca::createMenu(const QString &caption_, const QString &name_, VFo
     if (name.isEmpty()) {
         name += QLatin1Char('/');
     }
-    for (const KService::Ptr &p : qAsConst(menu->items)) {
+    for (const KService::Ptr &p : std::as_const(menu->items)) {
         if (m_menuTest) {
-            if (!menu->isDeleted && !p->noDisplay())
-                printf("%s\t%s\t%s\n", qPrintable(caption), qPrintable(p->menuId()),
+            if (!menu->isDeleted && !p->noDisplay()) {
+                printf("%s\t%s\t%s\n",
+                       qPrintable(caption),
+                       qPrintable(p->menuId()),
                        qPrintable(QStandardPaths::locate(QStandardPaths::ApplicationsLocation, p->entryPath())));
+            }
         } else {
             m_buildServiceGroupFactory->addNewEntryTo(name, p);
         }
@@ -370,13 +362,13 @@ bool KBuildSycoca::recreate(bool incremental)
 
     QLockFile lockFile(path + QLatin1String(".lock"));
     if (!lockFile.tryLock()) {
-        qCDebug(SYCOCA) <<  "Waiting for already running" << KBUILDSYCOCA_EXENAME << "to finish.";
+        qCDebug(SYCOCA) << "Waiting for already running" << KBUILDSYCOCA_EXENAME << "to finish.";
         if (!lockFile.lock()) {
             qCWarning(SYCOCA) << "Couldn't lock" << path + QLatin1String(".lock");
             return false;
         }
         if (!needsRebuild()) {
-            //qCDebug(SYCOCA) << "Up-to-date, skipping.";
+            // qCDebug(SYCOCA) << "Up-to-date, skipping.";
             return true;
         }
     }
@@ -433,13 +425,13 @@ bool KBuildSycoca::recreate(bool incremental)
     if (build()) { // Parse dirs
         save(str); // Save database
         if (str->status() != QDataStream::Ok) { // Probably unnecessary now in Qt5, since QSaveFile detects write errors
-            database.cancelWriting();    // Error
+            database.cancelWriting(); // Error
         }
         delete str;
         str = nullptr;
 
-        //if we are currently via sudo, preserve the original owner
-        //as $HOME may also be that of another user rather than /root
+        // if we are currently via sudo, preserve the original owner
+        // as $HOME may also be that of another user rather than /root
 #ifdef Q_OS_UNIX
         if (qEnvironmentVariableIsSet("SUDO_UID")) {
             const int uid = qEnvironmentVariableIntValue("SUDO_UID");
@@ -494,17 +486,17 @@ void KBuildSycoca::save(QDataStream *str)
     str->device()->seek(0);
 
     (*str) << qint32(KSycoca::version());
-    //KSycocaFactory * servicetypeFactory = 0;
-    //KBuildMimeTypeFactory * mimeTypeFactory = 0;
+    // KSycocaFactory * servicetypeFactory = 0;
+    // KBuildMimeTypeFactory * mimeTypeFactory = 0;
     KBuildServiceFactory *serviceFactory = nullptr;
     auto lst = *factories();
-    for (KSycocaFactory* factory : qAsConst(lst)) {
+    for (KSycocaFactory *factory : std::as_const(lst)) {
         qint32 aId;
         qint32 aOffset;
         aId = factory->factoryId();
-        //if ( aId == KST_KServiceTypeFactory )
+        // if ( aId == KST_KServiceTypeFactory )
         //   servicetypeFactory = factory;
-        //else if ( aId == KST_KMimeTypeFactory )
+        // else if ( aId == KST_KMimeTypeFactory )
         //   mimeTypeFactory = static_cast<KBuildMimeTypeFactory *>( factory );
         if (aId == KST_KServiceFactory) {
             serviceFactory = static_cast<KBuildServiceFactory *>(factory);
@@ -524,19 +516,25 @@ void KBuildSycoca::save(QDataStream *str)
     for (auto it = m_allResourceDirs.constBegin(); it != m_allResourceDirs.constEnd(); ++it) {
         (*str) << it.value();
     }
+    (*str) << m_extraFiles.keys();
+    for (auto it = m_extraFiles.constBegin(); it != m_extraFiles.constEnd(); ++it) {
+        (*str) << it.value();
+    }
 
-    // Calculate per-servicetype/mimetype data
-    if (serviceFactory) serviceFactory->postProcessServices();
+    // Calculate per-servicetype/MIME type data
+    if (serviceFactory) {
+        serviceFactory->postProcessServices();
+    }
 
     // Here so that it's the last debug message
     qCDebug(SYCOCA) << "Saving";
 
     // Write factory data....
     lst = *factories();
-    for (KSycocaFactory* factory : qAsConst(lst)) {
+    for (KSycocaFactory *factory : std::as_const(lst)) {
         factory->save(*str);
         if (str->status() != QDataStream::Ok) { // ######## TODO: does this detect write errors, e.g. disk full?
-            return;    // error
+            return; // error
         }
     }
 
@@ -547,7 +545,7 @@ void KBuildSycoca::save(QDataStream *str)
 
     (*str) << qint32(KSycoca::version());
     lst = *factories();
-    for (KSycocaFactory* factory : qAsConst(lst)) {
+    for (KSycocaFactory *factory : std::as_const(lst)) {
         qint32 aId;
         qint32 aOffset;
         aId = factory->factoryId();
@@ -576,6 +574,16 @@ QStringList KBuildSycoca::factoryResourceDirs()
     return *dirs;
 }
 
+QStringList KBuildSycoca::factoryExtraFiles()
+{
+    QStringList files;
+    // these are the extra files cached by ksycoca
+    // and whose timestamps are checked
+    files += KMimeAssociations::mimeAppsFiles();
+
+    return files;
+}
+
 QStringList KBuildSycoca::existingResourceDirs()
 {
     static QStringList *dirs = nullptr;
@@ -584,15 +592,12 @@ QStringList KBuildSycoca::existingResourceDirs()
     }
     dirs = new QStringList(factoryResourceDirs());
 
-    for (QStringList::Iterator it = dirs->begin();
-            it != dirs->end();) {
-        QFileInfo inf(*it);
-        if (!inf.exists() || !inf.isReadable()) {
-            it = dirs->erase(it);
-        } else {
-            ++it;
-        }
-    }
+    auto checkDir = [](const QString &str) {
+        QFileInfo info(str);
+        return !info.exists() || !info.isReadable();
+    };
+    dirs->erase(std::remove_if(dirs->begin(), dirs->end(), checkDir), dirs->end());
+
     return *dirs;
 }
 
@@ -602,7 +607,15 @@ static quint32 updateHash(const QString &file, quint32 hash)
     if (fi.isReadable() && fi.isFile()) {
         // This was using buff.st_ctime (in Waldo's initial commit to kstandarddirs.cpp in 2001), but that looks wrong?
         // Surely we want to catch manual editing, while a chmod doesn't matter much?
-        hash += fi.lastModified().toSecsSinceEpoch();
+        qint64 timestamp = fi.lastModified().toSecsSinceEpoch();
+        // On some systems (i.e. Fedora Kinoite), all files in /usr have a last
+        // modified timestamp of 0 (UNIX Epoch). In this case, always assume
+        // the file as been changed.
+        if (timestamp == 0) {
+            static qint64 now = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
+            timestamp = now;
+        }
+        hash += timestamp;
     }
     return hash;
 }
@@ -613,13 +626,16 @@ quint32 KBuildSycoca::calcResourceHash(const QString &resourceSubDir, const QStr
     if (!QDir::isRelativePath(filename)) {
         return updateHash(filename, hash);
     }
-    const QStringList files = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, resourceSubDir + QLatin1Char('/') + filename);
+    const QString filePath = resourceSubDir + QLatin1Char('/') + filename;
+    const QString qrcFilePath = QStringLiteral(":/") + filePath;
+    const QStringList files =
+        QFileInfo::exists(qrcFilePath) ? QStringList{qrcFilePath} : QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, filePath);
     for (const QString &file : files) {
         hash = updateHash(file, hash);
     }
     if (hash == 0 && !filename.endsWith(QLatin1String("update_ksycoca"))
-            && !filename.endsWith(QLatin1String(".directory")) // bug? needs investigation from someone who understands the VFolder spec
-       ) {
+        && !filename.endsWith(QLatin1String(".directory")) // bug? needs investigation from someone who understands the VFolder spec
+    ) {
         if (files.isEmpty()) {
             // This can happen if the file was deleted between directory listing and the above locateAll
             qCDebug(SYCOCA) << "File not found anymore:" << filename << " -- probably deleted meanwhile";
@@ -641,13 +657,15 @@ bool KBuildSycoca::checkGlobalHeader()
     const KSycocaHeader header = KSycocaPrivate::self()->readSycocaHeader();
     Q_ASSERT(!header.prefixes.split(QLatin1Char(':')).contains(QDir::homePath()));
 
-    return (current_update_sig == header.updateSignature) &&
-            (current_language == header.language) &&
-            (current_prefixes == header.prefixes) &&
-            (header.timeStamp != 0);
+    return (current_update_sig == header.updateSignature) //
+        && (current_language == header.language) //
+        && (current_prefixes == header.prefixes) //
+        && (header.timeStamp != 0);
 }
 
 const char *KBuildSycoca::sycocaPath()
 {
     return s_cSycocaPath;
 }
+
+#include "moc_kbuildsycoca_p.cpp"
