@@ -8,13 +8,15 @@
 #ifndef KSYCOCAENTRY_H
 #define KSYCOCAENTRY_H
 
-#include <ksycocatype.h>
 #include <kservice_export.h>
+#include <ksycocatype.h>
 
 #include <QDataStream>
+#include <QExplicitlySharedDataPointer>
 #include <QStringList>
 #include <QVariant>
-#include <QExplicitlySharedDataPointer>
+
+#include <memory>
 
 class KSycocaEntryPrivate;
 
@@ -29,7 +31,6 @@ class KSycocaEntryPrivate;
  */
 class KSERVICE_EXPORT KSycocaEntry : public QSharedData
 {
-
 public:
     /*
      * constructs a invalid KSycocaEntry object
@@ -76,8 +77,8 @@ public:
     QString storageId() const;
 
     /**
-    * @return true if valid
-    */
+     * @return true if valid
+     */
     bool isValid() const;
 
     /**
@@ -113,8 +114,8 @@ public:
     bool isSeparator() const;
 
 protected:
-    KSycocaEntry(KSycocaEntryPrivate &d);
-    KSycocaEntryPrivate *d_ptr;
+    KSERVICE_NO_EXPORT explicit KSycocaEntry(KSycocaEntryPrivate &d);
+    std::unique_ptr<KSycocaEntryPrivate> const d_ptr;
 
 private:
     // All these need access to offset()
@@ -132,6 +133,7 @@ private:
      * @return the position of the entry in the sycoca file
      */
     int offset() const;
+    // exported for KSycocaDictTest
 
     Q_DISABLE_COPY(KSycocaEntry)
 
